% Magnetization evolution in ihMT-prepared TFL sequence
% Authors : 
% - Lucas SOUSTELLE (lucas.soustelle@univ-amu.fr)
% - Olivier M. GIRARD (olivier.girard@univ-amu.fr)
% - Guillaume DUHAMEL (guillaume.duhamel@univ-amu.fr)
% - Andreea HERTANU (andreea.hertanu@univ-amu.fr)
% 2021/05/13
% Aix Marseille Univ, CNRS, CRMBM, Marseille, France
% Copyrights: see LICENCE file

clear; close all;
set(0,'defaulttextinterpreter','latex')
set(0,'DefaultLegendInterpreter', 'latex')
set(0,'defaultaxesfontname','cmu sans serif')
Fontsize = 18; labelsize = 24; clabel = 40;

addpath(genpath('Tools'));
gamma   = 267.513 * 1e6; % rad/s/T
COLOR_LIST_ihMTR  = {[22 27 179]/255,[0 0 0]/255,[191 11 11]/255};

%% parameters
% Tissue, delays & sequence parameters
parx.R1f        = 1/1000e-3;    % s
parx.T2f        = 0.022/parx.R1f; % s
parx.R1b        = 1/1000e-3;    % s
parx.T2b        = 10.0e-6;      % s
parx.R          = 19;           % s-1; fast "kb"
parx.M0b        = 0.16; 
parx.M0f        = 1.0; 
parx.T1D_1      = 0.4e-3;       % s
parx.T1D_2      = 10e-3;         % s
fD              = 0.5;
parx.M0b_1      = fD*parx.M0b;
parx.M0b_2      = (1-fD)*parx.M0b;
parx.D          = 1/( sqrt(15) * parx.T2b ); % rad.s-1

PREP.delta_f    = 7e3;      % Hz 
PREP.r_Tukey    = 0.3;
PREP.N_BTR      = 1;
PREP.DualType   = 'ALT'; % 'SM' / 'ALT'
PREP.N_altern   = 1;
PREP.PI         = 1-5*PREP.r_Tukey/8;
PREP.AI         = 1-PREP.r_Tukey/2;
PREP.SimuAll    = false; % simulate P/M/PM/MP ; else only P/PM
RAGE.DummyDur   = 10.0; % sec
RAGE.subTR      = 6.5e-3;        % s

% experiments: maintain a constant B1RMS over TR (B1RMS_TR)
dB1             = [1.0];
NSHOT           = [4 28 52];
N_C1 = 30; N_B1 = numel(dB1); N_NSHOT = numel(NSHOT);
RAGE.FA_nom     = linspace(1,20,N_C1) /180*pi;    % rad
RAGE.B1RMS_TR   = 3.0*1e-6; % T
PREP.tau_sat    = [(1.0e-3*ones(1,N_C1*N_B1*N_NSHOT))];   % s
PREP.delta_t    = [(1.5e-3*ones(1,N_C1*N_B1*N_NSHOT))];   % s 
PREP.Npulses    = [(8*ones(1,N_C1*N_B1*N_NSHOT))];
PREP.BTR        = PREP.Npulses .* PREP.delta_t;

RAGE.N_subTR    = cell2mat(arrayfun(@(c) repmat(c,[1 N_C1*N_B1]),NSHOT,'UniformOutput',false));
RAGE.TR         = PREP.Npulses(1)*PREP.delta_t(1) + RAGE.N_subTR.*RAGE.subTR;
PREP.FA_sat     = RAGE.B1RMS_TR .*180*gamma*PREP.AI*PREP.tau_sat(1) ./ ...
                                (pi*sqrt(PREP.PI*PREP.Npulses(1)*PREP.tau_sat(1)./RAGE.TR)) .* dB1;
RAGE.FA         = repmat(RAGE.FA_nom,[1 N_C1*N_B1*N_NSHOT]) .* dB1;


%% Run
tic
start_parpool('local');
parfor ii = 1 : numel(RAGE.TR)
    [PREP_par(ii), RAGE_par(ii), parx_par(ii)] = parse_par_ihMT_RAGE(PREP,RAGE,parx,ii);
    [MT0(ii),MTs_P(ii),MTd_PM(ii)] = func_simu_ihMT_RAGE(PREP_par(ii),RAGE_par(ii),parx_par(ii));
end
toc

%% plot(B1RMS,ihMTR)
MT0_arr     = arrayfun(@(c) MT0(c).Z0_perTR(end),1:numel(PREP.FA_sat));
MTs_P_arr   = arrayfun(@(c) MTs_P(c).Z0_perTR(end),1:numel(PREP.FA_sat));
MTd_PM_arr  = arrayfun(@(c) MTd_PM(c).Z0_perTR(end),1:numel(PREP.FA_sat));
MTs_M_arr   = MTs_P_arr;
MTd_MP_arr  = MTd_PM_arr;
ihMTR_arr   = (MTs_P_arr+MTs_M_arr-MTd_PM_arr-MTd_MP_arr)./MT0_arr*100;

close all;
ihMTR   = reshape(ihMTR_arr,[N_C1 N_NSHOT]);
figure(1), set(gcf,'position',[50 50 600 500]); 
hold on
plot(RAGE.FA_nom(1:N_C1)*180/pi,ihMTR(:,1),'--','color',COLOR_LIST_ihMTR{2},'linewidth',2)
plot(RAGE.FA_nom(1:N_C1)*180/pi,ihMTR(:,2),'-.','color',COLOR_LIST_ihMTR{2},'linewidth',2)
plot(RAGE.FA_nom(1:N_C1)*180/pi,ihMTR(:,3),'color',COLOR_LIST_ihMTR{2},'linewidth',2)
plot([5 5],[0 15],'--','color',[0.5 0.5 0.5],'linewidth',2)
xlabel('\fontsize{11}{0}\boldmath \textbf{Readout flip angles ($^\circ$)}'), xlim([1 20])
ylabel('\fontsize{11}{0}\boldmath \textbf{ihMTR (\%)}'), ylim([0 15])
grid on
legend({'TR = 38 ms','TR = 194 ms','TR = 350 ms'},'location','northeast','fontsize',16)
set(gca,'FontSize',14)

