% Magnetization evolution in ihMT-prepared TFL sequence
% Authors : 
% - Lucas SOUSTELLE (lucas.soustelle@univ-amu.fr)
% - Olivier M. GIRARD (olivier.girard@univ-amu.fr)
% - Guillaume DUHAMEL (guillaume.duhamel@univ-amu.fr)
% - Andreea HERTANU (andreea.hertanu@univ-amu.fr)
% 2021/03/15
% Aix Marseille Univ, CNRS, CRMBM, Marseille, France
% Copyrights: see LICENCE file

clear; close all;
set(0,'defaulttextinterpreter','latex')
set(0,'DefaultLegendInterpreter', 'latex')
set(0,'defaultaxesfontname','cmu sans serif')
Fontsize = 18; labelsize = 24; clabel = 40;

addpath(genpath('Tools'));
gamma   = 267.513 * 1e6;                    % rad/s/T
COLOR_LIST_ihMTR  = {[22 27 179]/255,[0 0 0]/255,[191 11 11]/255};

%% parameters
% Tissue, delays & sequence parameters
parx.R1f        = 1/1000e-3;    % s
parx.T2f        = 0.022/parx.R1f; % s
parx.R1b        = 1/1000e-3;    % s
parx.T2b        = 10.0e-6;      % s
parx.R          = 19;           % s-1; fast "kb"
parx.M0b        = 0.16; 
parx.M0f        = 1.0; 
parx.T1D_1      = 0.4e-3;       % s
parx.T1D_2      = 10e-3;         % s
fD              = 0.5;
parx.M0b_1      = fD*parx.M0b;
parx.M0b_2      = (1-fD)*parx.M0b;
parx.D          = 1/( sqrt(15) * parx.T2b ); % rad.s-1

PREP.delta_f    = 7e3;      % Hz 
PREP.r_Tukey    = 0.3;
PREP.N_BTR      = 1;
PREP.DualType   = 'ALT'; % 'SM' / 'ALT'
PREP.N_altern   = 1;
PREP.PI         = 1-5*PREP.r_Tukey/8;
PREP.AI         = 1-PREP.r_Tukey/2;
PREP.SimuAll    = false; % simulate P/M/PM/MP ; else only P/PM
RAGE.DummyDur   = 10.0; % sec
RAGE.subTR      = 6.5e-3;        % s
RAGE.FA_nom     = 5 /180*pi;    % rad

% experiments: maintain a constant B1RMS over TR (B1RMS_TR) & vary B1
dB1             = [[0.9 1.0 1.1] [0.9 1.0 1.1]*0.8];
N_C1 = 60; N_B1 = numel(dB1);
RAGE.N_subTR    = [repmat((1:N_C1),[1 N_B1])];
PREP.tau_sat    = [(1.0e-3*ones(1,N_C1*N_B1))];   % s
PREP.delta_t    = [(1.5e-3*ones(1,N_C1*N_B1))];   % s 
PREP.Npulses    = [(8*ones(1,N_C1*N_B1))];
RAGE.B1RMS_TR   = [(3.0e-6*ones(1,N_C1*N_B1))]; % T
PREP.BTR        = PREP.Npulses .* PREP.delta_t;
for ii = 1 : N_C1
        RAGE.TR(ii)     = PREP.Npulses(ii)*PREP.delta_t(ii) + RAGE.N_subTR(ii)*RAGE.subTR;
        PREP.FA_sat(ii) = RAGE.B1RMS_TR(ii)*180*gamma*PREP.AI*PREP.tau_sat(ii) / ...
                            (pi*sqrt(PREP.PI*PREP.Npulses(ii)*PREP.tau_sat(ii)/RAGE.TR(ii)));
end
RAGE.TR     = repmat(RAGE.TR,[1 N_B1]);
dB1         = repmat(dB1,[N_C1 1]); dB1 = dB1(:)';
PREP.FA_sat = repmat(PREP.FA_sat,[1 N_B1]).*dB1;
RAGE.FA     = repmat(RAGE.FA_nom,[1 N_C1*N_B1]).*dB1;

%% Run
tic
start_parpool('local');
parfor ii = 1 : numel(PREP.FA_sat)
    [PREP_par(ii), RAGE_par(ii), parx_par(ii)] = parse_par_ihMT_RAGE(PREP,RAGE,parx,ii);
    [MT0(ii),MTs_P(ii),MTd_PM(ii)] = func_simu_ihMT_RAGE(PREP_par(ii),RAGE_par(ii),parx_par(ii));
end
toc


%% plot(TR,ihMTR)
MT0_arr     = arrayfun(@(c) MT0(c).Z0_perTR(end),1:numel(PREP.FA_sat));
MTs_P_arr   = arrayfun(@(c) MTs_P(c).Z0_perTR(end),1:numel(PREP.FA_sat));
MTd_PM_arr  = arrayfun(@(c) MTd_PM(c).Z0_perTR(end),1:numel(PREP.FA_sat));
MTs_M_arr   = MTs_P_arr;
MTd_MP_arr  = MTd_PM_arr;
ihMTR_arr   = (MTs_P_arr+MTs_M_arr-MTd_PM_arr-MTd_MP_arr)./MT0_arr*100;

ihMTR_arr    = reshape(ihMTR_arr,[N_C1 N_B1]);
dihMTR_V90      = (ihMTR_arr(:,1) - ihMTR_arr(:,4))./ihMTR_arr(:,1)*100;
dihMTR_V100     = (ihMTR_arr(:,2) - ihMTR_arr(:,5))./ihMTR_arr(:,2)*100;
dihMTR_V110     = (ihMTR_arr(:,3) - ihMTR_arr(:,6))./ihMTR_arr(:,3)*100;

figure(1), set(gcf,'position',[50 50 600 500]); 
hold on
plot(RAGE.TR(1:N_C1)*1e3,ihMTR_arr(:,1),'color',COLOR_LIST_ihMTR{1},'linewidth',2)
plot(RAGE.TR(1:N_C1)*1e3,ihMTR_arr(:,2),'color',COLOR_LIST_ihMTR{2},'linewidth',2)
plot(RAGE.TR(1:N_C1)*1e3,ihMTR_arr(:,3),'color',COLOR_LIST_ihMTR{3},'linewidth',2)
ylabel('\fontsize{11}{0}\boldmath \textbf{ihMTR (\%)}')
xlabel('\fontsize{11}{0}\boldmath \textbf{TR (ms)}')
axis([0 425 1 12])
legend({'rB$_1^+=0.9$','rB$_1^+=1.0$','rB$_1^+=1.1$'},'location','southeast','fontsize',20)
grid on
set(gca,'FontSize',14)






